@@ -7,9 +7,9 @@ use Nmap::Parser;
 use Exporter qw(import);
 use YAML::Tiny;
 
-our @EXPORT = qw(scan_ports create_config compare_config);
+our @EXPORT = qw(scan_ports create_config compare_config nmap_path);
 
-our $VERSION = '1.05';
+our $VERSION = '1.06';
 
 =for HTML <a href="https://travis-ci.org/jreisinger/App-Monport"><img src="https://travis-ci.org/jreisinger/App-Monport.svg?branch=master"></a>
 
